<?php
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

namespace Google\Service\Connectors\Resource;

use Google\Service\Connectors\ListRuntimeEntitySchemasResponse;

/**
 * The "runtimeEntitySchemas" collection of methods.
 * Typical usage is:
 *  <code>
 *   $connectorsService = new Google\Service\Connectors(...);
 *   $runtimeEntitySchemas = $connectorsService->runtimeEntitySchemas;
 *  </code>
 */
class ProjectsLocationsConnectionsRuntimeEntitySchemas extends \Google\Service\Resource
{
  /**
   * List schema of a runtime entities filtered by entity name.
   * (runtimeEntitySchemas.listProjectsLocationsConnectionsRuntimeEntitySchemas)
   *
   * @param string $parent Required. Parent resource of RuntimeEntitySchema
   * Format: projects/{project}/locations/{location}/connections/{connection}
   * @param array $optParams Optional parameters.
   *
   * @opt_param string filter Required. Filter Format: entity="{entityId}" Only
   * entity field is supported with literal equality operator. Accepted filter
   * example: entity="Order" Wildcards are not supported in the filter currently.
   * @opt_param int pageSize Page size.
   * @opt_param string pageToken Page token.
   * @return ListRuntimeEntitySchemasResponse
   */
  public function listProjectsLocationsConnectionsRuntimeEntitySchemas($parent, $optParams = [])
  {
    $params = ['parent' => $parent];
    $params = array_merge($params, $optParams);
    return $this->call('list', [$params], ListRuntimeEntitySchemasResponse::class);
  }
}

// Adding a class alias for backwards compatibility with the previous class name.
class_alias(ProjectsLocationsConnectionsRuntimeEntitySchemas::class, 'Google_Service_Connectors_Resource_ProjectsLocationsConnectionsRuntimeEntitySchemas');
