<?php
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

namespace Google\Service\PublicCertificateAuthority\Resource;

use Google\Service\PublicCertificateAuthority\ExternalAccountKey;

/**
 * The "externalAccountKeys" collection of methods.
 * Typical usage is:
 *  <code>
 *   $publiccaService = new Google\Service\PublicCertificateAuthority(...);
 *   $externalAccountKeys = $publiccaService->projects_locations_externalAccountKeys;
 *  </code>
 */
class ProjectsLocationsExternalAccountKeys extends \Google\Service\Resource
{
  /**
   * Creates a new ExternalAccountKey bound to the project.
   * (externalAccountKeys.create)
   *
   * @param string $parent Required. The parent resource where this
   * external_account_key will be created. Format:
   * projects/[project_id]/locations/[location]. At present only the "global"
   * location is supported.
   * @param ExternalAccountKey $postBody
   * @param array $optParams Optional parameters.
   * @return ExternalAccountKey
   * @throws \Google\Service\Exception
   */
  public function create($parent, ExternalAccountKey $postBody, $optParams = [])
  {
    $params = ['parent' => $parent, 'postBody' => $postBody];
    $params = array_merge($params, $optParams);
    return $this->call('create', [$params], ExternalAccountKey::class);
  }
}

// Adding a class alias for backwards compatibility with the previous class name.
class_alias(ProjectsLocationsExternalAccountKeys::class, 'Google_Service_PublicCertificateAuthority_Resource_ProjectsLocationsExternalAccountKeys');
